===
API
===

Command Line Interface
======================

.. click:: allfreqs.cli:main
    :prog: allfreqs
    :show-nested:

____

Python Module
=============

.. automodule:: allfreqs.allfreqs
    :members:
